@@ -64,7 +64,7 @@ public class TestMysqlTableOperations extends TestMysql {
             .withName("col_1")
             .withType(VARCHAR)
             .withComment("test_comment")
-            .withNullable(false)
+            .withNullable(true)
             .build());
     columns.add(
         JdbcColumn.builder()
@@ -478,7 +478,7 @@ public class TestMysqlTableOperations extends TestMysql {
     columns.add(
         JdbcColumn.builder()
             .withName("col_3")
-            .withType(Types.TimestampType.withoutTimeZone())
+            .withType(Types.TimestampType.withoutTimeZone(0))
             // MySQL 5.7 doesn't support nullable timestamp
             .withNullable(false)
             .withComment("timestamp")
@@ -563,7 +563,7 @@ public class TestMysqlTableOperations extends TestMysql {
     columns.add(
         JdbcColumn.builder()
             .withName("col_3")
-            .withType(Types.TimestampType.withoutTimeZone())
+            .withType(Types.TimestampType.withoutTimeZone(0))
             // MySQL 5.7 doesn't support nullable timestamp
             .withNullable(false)
             .withComment("timestamp")
@@ -573,7 +573,7 @@ public class TestMysqlTableOperations extends TestMysql {
         JdbcColumn.builder()
             .withName("col_4")
             .withType(Types.DateType.get())
-            .withNullable(false)
+            .withNullable(true)
             .withComment("date")
             .withDefaultValue(Column.DEFAULT_VALUE_NOT_SET)
             .build());
@@ -645,13 +645,13 @@ public class TestMysqlTableOperations extends TestMysql {
     columns.add(
         JdbcColumn.builder()
             .withName("col_8")
-            .withType(Types.TimeType.get())
+            .withType(Types.TimeType.of(0))
             .withNullable(false)
             .build());
     columns.add(
         JdbcColumn.builder()
             .withName("col_9")
-            .withType(Types.TimestampType.withoutTimeZone())
+            .withType(Types.TimestampType.withoutTimeZone(0))
             .withNullable(false)
             .build());
     columns.add(
@@ -1105,4 +1105,63 @@ public class TestMysqlTableOperations extends TestMysql {
     sql = MysqlTableOperations.deleteIndexDefinition(load, deleteIndex3);
     Assertions.assertEquals("DROP INDEX `uk_2`", sql);
   }
+
+  @Test
+  public void testCalculateDatetimePrecision() {
+    Assertions.assertNull(
+        TABLE_OPERATIONS.calculateDatetimePrecision("DATE", 10, 0),
+        "DATE type should return 0 precision");
+
+    Assertions.assertEquals(
+        1,
+        TABLE_OPERATIONS.calculateDatetimePrecision("TIME", 10, 0),
+        "TIME type should return 0 precision");
+
+    Assertions.assertEquals(
+        3,
+        TABLE_OPERATIONS.calculateDatetimePrecision("TIMESTAMP", 23, 0),
+        "TIMESTAMP type should return 0 precision");
+
+    Assertions.assertEquals(
+        6,
+        TABLE_OPERATIONS.calculateDatetimePrecision("DATETIME", 26, 0),
+        "TIMESTAMP type should return 0 precision");
+
+    Assertions.assertEquals(
+        0,
+        TABLE_OPERATIONS.calculateDatetimePrecision("timestamp", 19, 0),
+        "Lower case type name should work");
+
+    Assertions.assertNull(
+        TABLE_OPERATIONS.calculateDatetimePrecision("VARCHAR", 50, 0),
+        "Non-datetime type should return 0 precision");
+  }
+
+  @Test
+  public void testCalculateDatetimePrecisionWithUnsupportedDriverVersion() {
+    MysqlTableOperations operationsWithOldDriver =
+        new MysqlTableOperations() {
+          @Override
+          public String getMySQLDriverVersion() {
+            return "mysql-connector-java-8.0.11 (Revision: a0ca826f5cdf51a98356fdfb1bf251eb042f80bf)";
+          }
+
+          @Override
+          public boolean isMySQLDriverVersionSupported(String driverVersion) {
+            return false; // Simulate old driver
+          }
+        };
+
+    Assertions.assertNull(
+        operationsWithOldDriver.calculateDatetimePrecision("TIMESTAMP", 26, 0),
+        "TIMESTAMP type should return null for unsupported driver version");
+
+    Assertions.assertNull(
+        operationsWithOldDriver.calculateDatetimePrecision("DATETIME", 26, 0),
+        "DATETIME type should return null for unsupported driver version");
+
+    Assertions.assertNull(
+        operationsWithOldDriver.calculateDatetimePrecision("TIME", 16, 0),
+        "TIME type should return null for unsupported driver version");
+  }
 }
