@@ -26,4 +26,7 @@ cd ${iceberg_rest_server_dir}
 
 python bin/rewrite_config.py
 
+JAVA_OPTS+=" -XX:-UseContainerSupport"
+export JAVA_OPTS
+
 ./bin/gravitino-iceberg-rest-server.sh start
