@@ -278,33 +278,13 @@ const CreateCatalogDialog = props => {
           ...others
         } = prevProperties
 
-        if (
-          catalogBackend &&
-          ['rest', 'hive'].includes(catalogBackend) &&
-          ['lakehouse-iceberg', 'lakehouse-paimon'].includes(providerSelect)
-        ) {
-          properties = {
-            'catalog-backend': catalogBackend,
-            uri: uri,
-            ...others
-          }
-          warehouse && (properties['warehouse'] = warehouse)
-        } else if (catalogBackend && catalogBackend === 'filesystem' && providerSelect === 'lakehouse-paimon') {
-          properties = {
-            'catalog-backend': catalogBackend,
-            ...others
-          }
-          uri && (properties['uri'] = uri)
-        } else {
-          properties = {
-            uri: uri,
-            ...others
-          }
-          catalogBackend && (properties['catalog-backend'] = catalogBackend)
-          jdbcDriver && (properties['jdbc-driver'] = jdbcDriver)
-          jdbcUser && (properties['jdbc-user'] = jdbcUser)
-          jdbcPwd && (properties['jdbc-password'] = jdbcPwd)
-        }
+        properties = { ...others }
+        catalogBackend && (properties['catalog-backend'] = catalogBackend)
+        uri && (properties['uri'] = uri)
+        warehouse && (properties['warehouse'] = warehouse)
+        jdbcDriver && (properties['jdbc-driver'] = jdbcDriver)
+        jdbcUser && (properties['jdbc-user'] = jdbcUser)
+        jdbcPwd && (properties['jdbc-password'] = jdbcPwd)
         authType && (properties['authentication.type'] = authType)
         kerberosPrincipal && (properties['authentication.kerberos.principal'] = kerberosPrincipal)
         kerberosKeytabUri && (properties['authentication.kerberos.keytab-uri'] = kerberosKeytabUri)
