@@ -34,32 +34,60 @@ import {
   IconButton,
   InputLabel,
   TextField,
-  Typography
+  Typography,
+  Tooltip,
+  Switch
 } from '@mui/material'
 
 import Icon from '@/components/Icon'
 
 import { useAppDispatch } from '@/lib/hooks/useStore'
-import { linkVersion } from '@/lib/store/metalakes'
+import { linkVersion, updateVersion } from '@/lib/store/metalakes'
 
 import * as yup from 'yup'
 import { useForm, Controller, useFieldArray } from 'react-hook-form'
 import { yupResolver } from '@hookform/resolvers/yup'
-
+import { genUpdates } from '@/lib/utils'
 import { groupBy } from 'lodash-es'
 import { keyRegex } from '@/lib/utils/regex'
 import { useSearchParams } from 'next/navigation'
 import { useAppSelector } from '@/lib/hooks/useStore'
+import clsx from 'clsx'
 
 const defaultValues = {
-  uri: '',
+  uris: [{ name: '', uri: '', defaultUri: true }],
   aliases: [{ name: '' }],
   comment: '',
   propItems: []
 }
 
 const schema = yup.object().shape({
-  uri: yup.string().required(),
+  uris: yup
+    .array()
+    .of(
+      yup.object().shape({
+        uri: yup.string().when('name', {
+          is: name => !!name,
+          then: schema => schema.required(),
+          otherwise: schema => schema
+        })
+      })
+    )
+    .test('unique', 'Uri name must be unique', (uris, ctx) => {
+      const values = uris?.filter(l => !!l.name).map(l => l.name)
+      const duplicates = values.filter((value, index, self) => self.indexOf(value) !== index)
+
+      if (duplicates.length > 0) {
+        const duplicateIndex = values.lastIndexOf(duplicates[0])
+
+        return ctx.createError({
+          path: `uris.${duplicateIndex}.name`,
+          message: 'This URI name is duplicated'
+        })
+      }
+
+      return true
+    }),
   aliases: yup
     .array()
     .of(
@@ -128,6 +156,9 @@ const LinkVersionDialog = props => {
     resolver: yupResolver(schema)
   })
 
+  const defaultUriProps = watch('propItems').filter(item => item.defaultUri)[0]
+  const urisItems = watch('uris')
+
   const handleFormChange = ({ index, event }) => {
     let data = [...innerProps]
     data[index][event.target.name] = event.target.value
@@ -171,11 +202,29 @@ const LinkVersionDialog = props => {
     setValue('propItems', data)
   }
 
+  const onChangeDefaultUri = ({ index, event }) => {
+    fields.forEach((item, i) => {
+      if (i !== index) {
+        setValue(`uris.${i}.defaultUri`, false)
+      }
+    })
+    setValue(`uris.${index}.defaultUri`, event.target.checked)
+  }
+
   const { fields, append, remove } = useFieldArray({
     control,
     name: 'aliases'
   })
 
+  const {
+    fields: uris,
+    append: appendUri,
+    remove: removeUri
+  } = useFieldArray({
+    control,
+    name: 'uris'
+  })
+
   const watchAliases = watch('aliases')
 
   const handleClose = () => {
@@ -210,7 +259,16 @@ const LinkVersionDialog = props => {
         }, {})
 
         const schemaData = {
-          uri: data.uri,
+          uris: data.uris.reduce((acc, item) => {
+            if (item.name && item.uri) {
+              acc[item.name] = item.uri
+              if (item.defaultUri && !properties['default-uri-name']) {
+                properties['default-uri-name'] = item.name
+              }
+            }
+
+            return acc
+          }, {}),
           aliases: data.aliases.map(alias => alias.name).filter(aliasName => aliasName),
           comment: data.comment,
           properties
@@ -224,6 +282,26 @@ const LinkVersionDialog = props => {
               handleClose()
             }
           })
+        } else {
+          const reqData = { updates: genUpdates(cacheData, schemaData) }
+
+          if (reqData.updates.length !== 0) {
+            dispatch(
+              updateVersion({
+                metalake,
+                catalog,
+                type: catalogType,
+                schema: schemaName,
+                model,
+                version: cacheData.version,
+                data: reqData
+              })
+            ).then(res => {
+              if (!res.payload?.err) {
+                handleClose()
+              }
+            })
+          }
         }
       })
       .catch(err => {
@@ -240,9 +318,19 @@ const LinkVersionDialog = props => {
       const { properties = {} } = data
 
       setCacheData(data)
-      setValue('uri', data.uri)
       setValue('comment', data.comment)
 
+      const uris =
+        data.uris &&
+        Object.entries(data.uris).map(([name, uri]) => ({
+          name,
+          uri,
+          defaultUri: properties['default-uri-name'] === name
+        }))
+      setValue('uris', uris)
+      const aliases = data.aliases.map(alias => ({ name: alias }))
+      setValue(`aliases`, aliases)
+
       const propsItems = Object.entries(properties).map(([key, value]) => {
         return {
           key,
@@ -281,25 +369,103 @@ const LinkVersionDialog = props => {
 
           <Grid container spacing={6}>
             <Grid item xs={12}>
-              <FormControl fullWidth>
-                <Controller
-                  name='uri'
-                  control={control}
-                  rules={{ required: true }}
-                  render={({ field: { value, onChange } }) => (
-                    <TextField
-                      value={value}
-                      label='URI'
-                      onChange={onChange}
-                      placeholder=''
-                      disabled={type === 'update'}
-                      error={Boolean(errors.uri)}
-                      data-refer='link-uri-field'
-                    />
-                  )}
-                />
-                {errors.uri && <FormHelperText sx={{ color: 'error.main' }}>{errors.uri.message}</FormHelperText>}
-              </FormControl>
+              <Typography sx={{ mb: 2 }} variant='body2'>
+                Uris
+              </Typography>
+              {uris.map((field, index) => {
+                return (
+                  <Grid key={index} item xs={12} sx={{ '& + &': { mt: 2 } }}>
+                    <FormControl fullWidth>
+                      <Box
+                        key={field.id}
+                        sx={{ display: 'flex', alignItems: 'center', justifyContent: 'space-between', gap: 1 }}
+                        data-refer={`uris-${index}`}
+                      >
+                        <Box className={clsx(uris.length === 1 && uris[index]?.name === 'unknown' ? 'twc-hidden' : '')}>
+                          <Controller
+                            name={`uris.${index}.name`}
+                            control={control}
+                            render={({ field: { value, onChange } }) => (
+                              <TextField
+                                {...field}
+                                value={value}
+                                onChange={onChange}
+                                label={`Name ${index + 1}`}
+                                data-refer={`uris-name-${index}`}
+                                error={!!errors.uris?.[index]?.name || !!errors.uris?.message}
+                                helperText={errors.uris?.[index]?.name?.message || errors.uris?.message}
+                                fullWidth
+                              />
+                            )}
+                          />
+                        </Box>
+                        <Box sx={{ flexGrow: 1 }}>
+                          <Controller
+                            name={`uris.${index}.uri`}
+                            control={control}
+                            render={({ field: { value, onChange } }) => (
+                              <TextField
+                                {...field}
+                                value={value}
+                                onChange={onChange}
+                                label={`URI ${index + 1}`}
+                                data-refer={`uris-uri-${index}`}
+                                error={!!errors.uris?.[index]?.uri || !!errors.uris?.message}
+                                helperText={errors.uris?.[index]?.uri?.message || errors.uris?.message}
+                                fullWidth
+                              />
+                            )}
+                          />
+                        </Box>
+                        {!defaultUriProps && urisItems.length > 1 && urisItems[0].name && urisItems[0].uri && (
+                          <Box>
+                            <Controller
+                              name={`uris.${index}.defaultUri`}
+                              control={control}
+                              render={({ field: { value, onChange } }) => (
+                                <Tooltip title='Default URI' placement='top'>
+                                  <Switch
+                                    checked={value}
+                                    onChange={event => onChangeDefaultUri({ index, event })}
+                                    disabled={type === 'update'}
+                                    size='small'
+                                  />
+                                </Tooltip>
+                              )}
+                            />
+                          </Box>
+                        )}
+                        <Box>
+                          {index === 0 ? (
+                            <Box sx={{ minWidth: 40 }}>
+                              <IconButton
+                                sx={{ cursor: 'pointer' }}
+                                onClick={() => {
+                                  appendUri({ name: '', uri: '' })
+                                }}
+                              >
+                                <Icon icon='mdi:plus-circle-outline' />
+                              </IconButton>
+                            </Box>
+                          ) : (
+                            <Box sx={{ minWidth: 40 }}>
+                              <IconButton
+                                sx={{ cursor: 'pointer' }}
+                                onClick={() => {
+                                  removeUri(index)
+                                }}
+                              >
+                                <Icon icon='mdi:minus-circle-outline' />
+                              </IconButton>
+                            </Box>
+                          )}
+                        </Box>
+                      </Box>
+                    </FormControl>
+                  </Grid>
+                )
+              })}
+              {errors.uris && <FormHelperText sx={{ color: 'error.main' }}>{errors.uris.message}</FormHelperText>}
             </Grid>
 
             <Grid item xs={12}>
@@ -334,13 +500,23 @@ const LinkVersionDialog = props => {
                         <Box>
                           {index === 0 ? (
                             <Box sx={{ minWidth: 40 }}>
-                              <IconButton onClick={() => append({ name: '' })}>
+                              <IconButton
+                                sx={{ cursor: type === 'update' ? 'not-allowed' : 'pointer' }}
+                                onClick={() => {
+                                  append({ name: '' })
+                                }}
+                              >
                                 <Icon icon='mdi:plus-circle-outline' />
                               </IconButton>
                             </Box>
                           ) : (
                             <Box sx={{ minWidth: 40 }}>
-                              <IconButton onClick={() => remove(index)}>
+                              <IconButton
+                                sx={{ cursor: type === 'update' ? 'not-allowed' : 'pointer' }}
+                                onClick={() => {
+                                  remove(index)
+                                }}
+                              >
                                 <Icon icon='mdi:minus-circle-outline' />
                               </IconButton>
                             </Box>
